# Produce the simulation parameters for all simulations

config <- yaml::read_yaml(here::here("config.yaml"))

# Currently this has exactly the parameters required by {splatter}.
standard_sim <- list(
  de.facLoc = 2,
  group.prob = rep(1 / 5, 5),
  batchCells = 1000,
  seed = 10
)

n_sims <- 3
sim_pars <- rep(list(standard_sim), n_sims)
names(sim_pars) <- paste0("sim_", 1:n_sims)

# Write out the simulation ids to a (json) file.
sim_ids <- names(sim_pars)
write(jsonlite::toJSON(sim_ids), config$sim_ids_path)

# FIXME
# Construct the paths of the simulation ids.
# dir.create(config$sim_pars_folder, showWarnings = FALSE)

sim_paths <- here::here(config$sim_pars_folder, sim_ids)
sim_paths <- paste0(sim_paths, ".json")
names(sim_paths) <- sim_ids

# Write all the parameters of each simulation to file.
# The checking of previous parameters is needed so that we don't constantly
# make the files newer, breaking Snakemake.
# FIXME: How can we clean up out of date parameter files?
for (id in sim_ids) {
  new <- sim_pars[[id]]
  path <- sim_paths[[id]]

  if (file.exists(path)) {

    old <- jsonlite::fromJSON(path)
    # Account for small floating point differences.
    if (!isTRUE(all.equal(old, new, tolerance = 1e-3))) {
      write(jsonlite::toJSON(new, null = "null"), path)
    }

  } else {
    write(jsonlite::toJSON(new, null = "null"), path)
  }
}
